@@ -3,10 +3,22 @@ package CPU::Emulator::6502::Op::STX;
 use strict;
 use warnings;
 
-use constant ADDRESSING => {
-    zero_page   => 0x86,
-    zero_page_y => 0x96,
-    absolute    => 0x8E,
+use constant INSTRUCTIONS => {
+    0x86 => {
+        addressing => 'zero_page',
+        cycles => 3,
+        code => \&stx,
+    },
+    0x96 => {
+        addressing => 'zero_page_y',
+        cycles => 4,
+        code => \&stx,
+    },
+    0x8E => {
+        addressing => 'absolute',
+        cycles => 4,
+        code => \&stx,
+    },
 };
 
 =head1 NAME
@@ -19,23 +31,15 @@ CPU::Emulator::6502::Op::STX - Store the X register in memory
 
 =head1 METHODS
 
-=head2 zero_page( )
+=head2 stx( $addr )
 
-=head2 zero_page_y( )
-
-=head2 absolute( )
-
-=head2 do_op( )
+Stores the X register in memory address C<$addr>.
 
 =cut
 
-*zero_page = \&do_op;
-*zero_page_y = \&do_op;
-*absolute = \&do_op;
-
-sub do_op {
+sub stx {
     my $self = shift;
-    $self->RAM_write( $self->temp2, $self->registers->{ x } );
+    $self->RAM_write( shift, $self->registers->{ x } );
 }
 
 =head1 AUTHOR
