@@ -3,8 +3,11 @@ package CPU::Emulator::6502::Op::TAY;
 use strict;
 use warnings;
 
-use constant ADDRESSING => {
-    implied => 0xA8,
+use constant INSTRUCTIONS => {
+    0xA8 => {
+        cycles => 2,
+        code   => \&tay
+    },
 };
 
 =head1 NAME
@@ -17,22 +20,18 @@ CPU::Emulator::6502::Op::TAY - Transfer the accumulator to the Y register
 
 =head1 METHODS
 
-=head2 implied( )
+=head2 tay( )
+
+Does the transfer of the accumulator to the Y register.
 
 =cut
 
-sub implied {
+sub tay {
     my $self = shift;
     my $reg = $self->registers;
 
     $reg->{ y } = $reg->{ acc };
-    $reg->{ status } &= CPU::Emulator::6502::CLEAR_SIGN;
-    $reg->{ status } &= CPU::Emulator::6502::CLEAR_ZERO;
-
-    $reg->{ status } |= CPU::Emulator::6502::SET_SIGN if $reg->{ y } & 0x80;
-    $reg->{ status } |= CPU::Emulator::6502::SET_ZERO if $reg->{ y } == 0;
-
-    $reg->{ pc }++;
+    $self->set_nz( $reg->{ y } );
 }
 
 =head1 AUTHOR
